@@ -614,9 +614,6 @@ class Eniam():
             try:
                 line = q_out.get_nowait()
             except Empty:
-                if start_time is not None:
-                    if (time.time() - start_time > 3):
-                        break
                 if (time.time() - pipe_start_time > 20) and (start_time is None):
                     raise Exception("Parser timeout")
                 time.sleep(1)
@@ -634,6 +631,8 @@ class Eniam():
                     output_err.append(line_content)
                 if line_content.startswith("<!DOCTYPE"):
                     collect_output = True
+                if line_content.startswith("@done@"):
+                    break
                 if line_content.startswith("@end_png@"):
                     collect_png = False
                 else:
